@@ -13,10 +13,10 @@ cat("\n")
 
 if(length(x$deleted.blocks)>1){
 cat("Warning:","\n")
-cat("Blocks", sort(x$deleted.blocks), "have been removed because they provided negative or atypical variances.","\n")
+cat("Blocks", sort(x$deleted.blocks), "have been removed because they provided negative variances.","\n")
 }else if(length(x$deleted.blocks)==1&is.na(x$deleted.blocks)==F&is.infinite(x$deleted.blocks)==F){
 cat("Warning:","\n")
-cat("Block", sort(x$deleted.blocks), "has been removed because it provided negative or atypical variance.","\n")
+cat("Block", sort(x$deleted.blocks), "has been removed because it provided negative variance.","\n")
 }
 
 cat("\n")
